use crate::prelude::*;
use argon2::PasswordHasher;
use argon2::PasswordVerifier;
use argon2::{password_hash::SaltString, Argon2, PasswordHash};

pub fn password_digest<P: AsRef<[u8]>>(
    password: P,
) -> Result<String, argon2::password_hash::Error> {
    let argon2 = Argon2::default();
    let salt = SaltString::generate(&mut argon2::password_hash::rand_core::OsRng);
    Ok(argon2.hash_password(password.as_ref(), &salt)?.to_string())
}

pub fn verified_password<S: AsRef<str>, P: AsRef<[u8]>>(
    password: P,
    password_digest: S,
) -> Result<(), argon2::password_hash::Error> {
    Argon2::default().verify_password(
        password.as_ref(),
        &PasswordHash::new(password_digest.as_ref())?,
    )
}
